==> nodejs_0.10.25~dfsg2.orig.tar.gz: node-v0.10.25~dfsg2/test/message/2100bytes.js <==
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.




var common = require('../common');
var assert = require('assert');
var util = require('util');

console.log([
  '_______________________________________________50',
  '______________________________________________100',
  '______________________________________________150',
  '______________________________________________200',
  '______________________________________________250',
  '______________________________________________300',
  '______________________________________________350',
  '______________________________________________400',
  '______________________________________________450',
  '______________________________________________500',
  '______________________________________________550',
  '______________________________________________600',
  '______________________________________________650',
  '______________________________________________700',
  '______________________________________________750',
  '______________________________________________800',
  '______________________________________________850',
  '______________________________________________900',
  '______________________________________________950',
  '_____________________________________________1000',
  '_____________________________________________1050',
  '_____________________________________________1100',
  '_____________________________________________1150',
  '_____________________________________________1200',
  '_____________________________________________1250',
  '_____________________________________________1300',
  '_____________________________________________1350',
  '_____________________________________________1400',
  '_____________________________________________1450',
  '_____________________________________________1500',
  '_____________________________________________1550',
  '_____________________________________________1600',
  '_____________________________________________1650',
  '_____________________________________________1700',
  '_____________________________________________1750',
  '_____________________________________________1800',
  '_____________________________________________1850',
  '_____________________________________________1900',
  '_____________________________________________1950',
  '_____________________________________________2000',
  '_____________________________________________2050',
  '_____________________________________________2100'
].join('\n'));

==> nodejs_4.7.2~dfsg.orig.tar.gz: node-v4.7.2/test/message/2100bytes.js <==
'use strict';
require('../common');

console.log([
  '_______________________________________________50',
  '______________________________________________100',
  '______________________________________________150',
  '______________________________________________200',
  '______________________________________________250',
  '______________________________________________300',
  '______________________________________________350',
  '______________________________________________400',
  '______________________________________________450',
  '______________________________________________500',
  '______________________________________________550',
  '______________________________________________600',
  '______________________________________________650',
  '______________________________________________700',
  '______________________________________________750',
  '______________________________________________800',
  '______________________________________________850',
  '______________________________________________900',
  '______________________________________________950',
  '_____________________________________________1000',
  '_____________________________________________1050',
  '_____________________________________________1100',
  '_____________________________________________1150',
  '_____________________________________________1200',
  '_____________________________________________1250',
  '_____________________________________________1300',
  '_____________________________________________1350',
  '_____________________________________________1400',
  '_____________________________________________1450',
  '_____________________________________________1500',
  '_____________________________________________1550',
  '_____________________________________________1600',
  '_____________________________________________1650',
  '_____________________________________________1700',
  '_____________________________________________1750',
  '_____________________________________________1800',
  '_____________________________________________1850',
  '_____________________________________________1900',
  '_____________________________________________1950',
  '_____________________________________________2000',
  '_____________________________________________2050',
  '_____________________________________________2100'
].join('\n'));
